<?php
namespace Teknisa\OPL\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;

class CookieController {
    const NOME_ARQUIVO_OPL          = "NOME_ARQUIVO_OPL";
    const BODY_MAIL_ANEXO_OPL       = "BODY_MAIL_ANEXO_OPL";
    const SUBJECT_MAIL_OPL          = "SUBJECT_MAIL_OPL";
    const SEND_TO_OPERATOR_OPL      = "SEND_TO_OPERATOR_OPL";
    const EMAILS_LIST_OPL           = "EMAILS_LIST_OPL";
    
    protected $crudService;
    protected $environment;
    protected $oplUtilities;
    
    public function __construct($crudService, $parameterBag, $environment, $oplUtilities)  {
        $this->crudService  = $crudService;
        $this->environment = $environment;
        $this->oplUtilities = $oplUtilities;
    }
    
    public function setCookie($currentRow, $dadosEmail) {
        if (strpos($dadosEmail['MENSAGEM'], 'data:image') == false) {
            $dadosEmail['MENSAGEM'] = str_replace('src="', 'src="data:image', $dadosEmail['MENSAGEM']);
        }
        
        $this->oplUtilities->defineCookieEmail(self::NOME_ARQUIVO_OPL, $dadosEmail['NOME_ARQUIVO'], time() + (86400 * 999));
        $this->oplUtilities->defineCookieEmail(self::BODY_MAIL_ANEXO_OPL, $dadosEmail['MENSAGEM'], time() + (86400 * 999));
        $this->oplUtilities->defineCookieEmail(self::SUBJECT_MAIL_OPL, $dadosEmail['ASSUNTO'], time() + (86400 * 999));
        $this->oplUtilities->defineCookieEmail(self::EMAILS_LIST_OPL, $dadosEmail['EMAILS'], time() + (86400 * 999));
        $this->oplUtilities->defineCookieEmail(self::SEND_TO_OPERATOR_OPL, $dadosEmail['SENDOPERATOR'], time() + (86400 * 999));
    }
    
    public function defineCookieEmail(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $dadosEmail = $row['DADOS_EMAIL'];
            $currentRow = $row['CURRENT_ROW'];
            
            $this->setCookie($currentRow, $dadosEmail);
            
            $response->addMessage(new Message('Cookie successful'));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function retornaCookieEmail(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $isResend = false;
            
            if(count($row)) {
                $isResend = isset($row['ISRESENDEMAIL']) ? $row['ISRESENDEMAIL'] : false;
            }

            if($isResend) {
                $body = $row['IDTPENVAFNORMAL'] === 'E' ? self::BODY_RESEND_MAIL_ANEXO : self::BODY_RESEND_MAIL_PORTAL;
                $assunto = $this->oplUtilities->retornaCookieEmail(self::SUBJECT_RESEND_MAIL);
                $mensagem = $this->oplUtilities->retornaCookieEmail($body);    
                $copyToOperator = $this->oplUtilities->retornaCookieEmail(self::RESEND_TO_OPERATOR);
            } else {
                $body = $row['IDTPENVAFNORMAL'] === 'E' ? self::BODY_MAIL_ANEXO : self::BODY_MAIL_PORTAL;
                $assunto = $this->oplUtilities->retornaCookieEmail(self::SUBJECT_MAIL);
                $mensagem = $this->oplUtilities->retornaCookieEmail($body);
                $copyToOperator = $this->oplUtilities->retornaCookieEmail(self::SEND_TO_OPERATOR);
            }
            
            if(empty($assunto) && $row['DEFAULT_MAIL_SUBJECT']) {
                $assunto = $row['DEFAULT_MAIL_SUBJECT'];
            }
            
            if(empty($mensagem)) {
                $mensagem = $row['IDTPENVAFNORMAL'] === 'E' ? $row['DEFAULT_MAIL_ANEXO_BODY'] : $row['DEFAULT_MAIL_PORTAL_BODY'];
                $mensagem = $mensagem . $this->environment->getCurrentUserName();
            }
            
            $msgLink = $this->oplUtilities->retornaCookieEmail(self::MSG_EMAIL_VISUALIZA);
            
            if(empty($msgLink) && $row['MSG_EMAIL_VISUALIZA']) {
                $msgLink = $row['MSG_EMAIL_VISUALIZA'];
            }
            
            $msgEmailAuto = $this->oplUtilities->retornaCookieEmail(self::MSG_EMAIL_AUTO);

            if(empty($msgEmailAuto) && $row['MSG_EMAIL_AUTO']) {
                $msgEmailAuto = $row['MSG_EMAIL_AUTO'];
            }
            
            $msgDateSent = $this->oplUtilities->retornaCookieEmail(self::MSG_DATE_SENT);

            if(empty($msgDateSent) && $row['MSG_DATE_SENT']) {
                $msgDateSent = $row['MSG_DATE_SENT'];
            }
            
            if(empty($copyToOperator)) {
                $copyToOperator = self::getConfigalcada();
            }

            $response->addMessage(new Message($assunto));
            $response->addMessage(new Message($mensagem));
            $response->addMessage(new Message($msgLink));
            $response->addMessage(new Message($msgEmailAuto));
            $response->addMessage(new Message($msgDateSent));
            $response->addMessage(new Message($copyToOperator));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    private function getConfigalcada() {
        $dataSourceName = 'configalcada';
        $conditions = array(array('columnName' => 'NRORG', 'operator' => '=', "value" => $this->environment->getNrOrg()));
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
        
        return is_array($dataSet) && count($dataSet) ? 'S' : 'N';
    }
    
    public function retornaCookieByName(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
        
            $cookie = $this->oplUtilities->retornaCookieEmail($row['COOKIE_NAME']);
        
            $response->addMessage(new Message($cookie));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}